@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.008001;
 
-our $VERSION = '0.55';
+our $VERSION = '0.56';
 
 use Carp qw(croak);
 use URI ();
@@ -13,7 +13,7 @@ use JSON;
 use HTML::Entities qw/decode_entities/;
 use HTTP::Request;
 
-$Carp::Intrenal{ (__PACKAGE__) }++;
+$Carp::Internal{ (__PACKAGE__) }++;
 
 use constant DEFAULT_FMT => 18;
 
